@@ -375,8 +375,6 @@ def run_seetm_cli() -> NoReturn:
                 case=case,
                 interface=InterfaceType.MAPPER,
             )
-            print(configs)
-            exit()
             seetm_cli_mapper = SEETMCLIMapper(
                 configs=configs,
                 persist=persist,
